==> ejc-zdsmaterialb-api-3.0.0-20241015.015712-31-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/BrandRelationVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 品牌关系
 * 
 * @author generator
 * 
 */
public class BrandRelationVO extends BaseVO {

    private static final long serialVersionUID = -2400078419598494093L;
    private String sourceId;//第三方业务单据Id
    private Long materialTypeId; // 物料分类id
    private String materialTypeSid; // 物料分类sid
    private String materialTypeName; // 物料分类名称
    private String materialTypeCode; // 物料分类编码
    private String materialTypePname; // 上级物料分类名称
    private Long materialTypePid; // 上级物料分类id
    private String materialTypePsid; // 上级物料分类sid
    private Long brandId; // 品牌id
    private String brandName; // 品牌名称
    private String brandSid; // 品牌来源id
    private Long supplierId; // 供应商id
    private String supplierCode;//供应商编码
    private String supplierName; // 供应商名称
    private String supplierSid; // 供应商sid
    private String supplierCharacter; //供应商性质：0-生产商，1-供应商
    private Integer dbSupplierFlag; // 供应商是否在库 0-否，1-是
    private Integer relationEnabled; // 停启用：0-停用，1-启用
    private String memo; // 备注
    private Integer pushErpFlag; // 推送ERP标识：0-待推送，1-已推送，2-推送失败

    private Long sourceMainId;//数据来源业务主表id
    private Long sourceDetailId; //数据来源业务字表id

    private Integer brandEnabled; //品牌停启用:0-停用，1-启用
    private Integer brandSequence; //序号
    private String brandLabel; //品牌标签 0-代理，1-直签，2-代理/直签
    private String delFlag; //是否删除 0-否，1-是
    private Long operatorId;//操作人Id
    private String operateType; //操作类型
    private String BillType;//单据类型
    private String pcUrl;//单据详情链接

    private boolean generateFlowFlag; //是否生成流水

    private List<BrandRelationFlowVO> detailList = new ArrayList<>(); // 品牌关系流水

    public boolean isGenerateFlowFlag() {
        return generateFlowFlag;
    }

    public void setGenerateFlowFlag(boolean generateFlowFlag) {
        this.generateFlowFlag = generateFlowFlag;
    }

    public String getBillType() {
        return BillType;
    }

    public void setBillType(String billType) {
        BillType = billType;
    }

    public String getOperateType() {
        return operateType;
    }

    public void setOperateType(String operateType) {
        this.operateType = operateType;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public Long getSourceMainId() {
        return sourceMainId;
    }

    public void setSourceMainId(Long sourceMainId) {
        this.sourceMainId = sourceMainId;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }

    public String getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(String delFlag) {
        this.delFlag = delFlag;
    }

    public String getBrandLabel() {
        return brandLabel;
    }

    public void setBrandLabel(String brandLabel) {
        this.brandLabel = brandLabel;
    }

    public Integer getBrandEnabled() {
        return brandEnabled;
    }

    public void setBrandEnabled(Integer brandEnabled) {
        this.brandEnabled = brandEnabled;
    }

    public Integer getBrandSequence() {
        return brandSequence;
    }

    public void setBrandSequence(Integer brandSequence) {
        this.brandSequence = brandSequence;
    }

    public String getSupplierCharacter() {
        return supplierCharacter;
    }

    public void setSupplierCharacter(String supplierCharacter) {
        this.supplierCharacter = supplierCharacter;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeSid() {
        return materialTypeSid;
    }

    public void setMaterialTypeSid(String materialTypeSid) {
        this.materialTypeSid = materialTypeSid;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypePname() {
        return materialTypePname;
    }

    public void setMaterialTypePname(String materialTypePname) {
        this.materialTypePname = materialTypePname;
    }
    public Long getMaterialTypePid() {
        return materialTypePid;
    }

    public void setMaterialTypePid(Long materialTypePid) {
        this.materialTypePid = materialTypePid;
    }
    public String getMaterialTypePsid() {
        return materialTypePsid;
    }

    public void setMaterialTypePsid(String materialTypePsid) {
        this.materialTypePsid = materialTypePsid;
    }
    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    public String getBrandSid() {
        return brandSid;
    }

    public void setBrandSid(String brandSid) {
        this.brandSid = brandSid;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSid() {
        return supplierSid;
    }

    public void setSupplierSid(String supplierSid) {
        this.supplierSid = supplierSid;
    }
    public Integer getDbSupplierFlag() {
        return dbSupplierFlag;
    }

    public void setDbSupplierFlag(Integer dbSupplierFlag) {
        this.dbSupplierFlag = dbSupplierFlag;
    }
    public Integer getRelationEnabled() {
        return relationEnabled;
    }

    public void setRelationEnabled(Integer relationEnabled) {
        this.relationEnabled = relationEnabled;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getPushErpFlag() {
        return pushErpFlag;
    }

    public void setPushErpFlag(Integer pushErpFlag) {
        this.pushErpFlag = pushErpFlag;
    }

    public List<BrandRelationFlowVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<BrandRelationFlowVO> detailList) {
        this.detailList = detailList;
    }

    public String getPcUrl() {
        return pcUrl;
    }

    public void setPcUrl(String pcUrl) {
        this.pcUrl = pcUrl;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20251028.071144-67-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/BrandRelationVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 品牌关系
 * 
 * @author generator
 * 
 */
public class BrandRelationVO extends BaseVO {

    private static final long serialVersionUID = -2400078419598494093L;
    private String sourceId;//第三方业务单据Id
    private Long materialTypeId; // 物料分类id
    private String materialTypeSid; // 物料分类sid
    private String materialTypeName; // 物料分类名称
    private String materialTypeCode; // 物料分类编码
    private String materialTypePname; // 上级物料分类名称
    private Long materialTypePid; // 上级物料分类id
    private String materialTypePsid; // 上级物料分类sid
    private Long brandId; // 品牌id
    private String brandName; // 品牌名称
    private String brandSid; // 品牌来源id
    private Long supplierId; // 供应商id
    private String supplierCode;//供应商编码
    private String supplierName; // 供应商名称
    private String supplierSid; // 供应商sid
    private String supplierCharacter; //供应商供货内容性质：0-生产商，1-贸易商-代理型，2-贸易商-项目授权型
    private Integer dbSupplierFlag; // 供应商是否在库 0-否，1-是
    private Integer relationEnabled; // 停启用：0-停用，1-启用
    private String memo; // 备注
    private Integer pushErpFlag; // 推送ERP标识：0-待推送，1-已推送，2-推送失败

    private Long sourceMainId;//数据来源业务主表id
    private Long sourceDetailId; //数据来源业务字表id

    private Integer brandEnabled; //品牌停启用:0-停用，1-启用
    private Integer brandSequence; //序号
    private String brandLabel; //品牌标签 0-代理，1-直签，2-代理/直签
    private String delFlag; //是否删除 0-否，1-是
    private Long operatorId;//操作人Id
    private String operateType; //操作类型
    private String BillType;//单据类型
    private String pcUrl;//单据详情链接

    private boolean generateFlowFlag; //是否生成流水

    private List<BrandRelationFlowVO> detailList = new ArrayList<>(); // 品牌关系流水

    public boolean isGenerateFlowFlag() {
        return generateFlowFlag;
    }

    public void setGenerateFlowFlag(boolean generateFlowFlag) {
        this.generateFlowFlag = generateFlowFlag;
    }

    public String getBillType() {
        return BillType;
    }

    public void setBillType(String billType) {
        BillType = billType;
    }

    public String getOperateType() {
        return operateType;
    }

    public void setOperateType(String operateType) {
        this.operateType = operateType;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public Long getSourceMainId() {
        return sourceMainId;
    }

    public void setSourceMainId(Long sourceMainId) {
        this.sourceMainId = sourceMainId;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }

    public String getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(String delFlag) {
        this.delFlag = delFlag;
    }

    public String getBrandLabel() {
        return brandLabel;
    }

    public void setBrandLabel(String brandLabel) {
        this.brandLabel = brandLabel;
    }

    public Integer getBrandEnabled() {
        return brandEnabled;
    }

    public void setBrandEnabled(Integer brandEnabled) {
        this.brandEnabled = brandEnabled;
    }

    public Integer getBrandSequence() {
        return brandSequence;
    }

    public void setBrandSequence(Integer brandSequence) {
        this.brandSequence = brandSequence;
    }

    public String getSupplierCharacter() {
        return supplierCharacter;
    }

    public void setSupplierCharacter(String supplierCharacter) {
        this.supplierCharacter = supplierCharacter;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeSid() {
        return materialTypeSid;
    }

    public void setMaterialTypeSid(String materialTypeSid) {
        this.materialTypeSid = materialTypeSid;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypePname() {
        return materialTypePname;
    }

    public void setMaterialTypePname(String materialTypePname) {
        this.materialTypePname = materialTypePname;
    }
    public Long getMaterialTypePid() {
        return materialTypePid;
    }

    public void setMaterialTypePid(Long materialTypePid) {
        this.materialTypePid = materialTypePid;
    }
    public String getMaterialTypePsid() {
        return materialTypePsid;
    }

    public void setMaterialTypePsid(String materialTypePsid) {
        this.materialTypePsid = materialTypePsid;
    }
    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    public String getBrandSid() {
        return brandSid;
    }

    public void setBrandSid(String brandSid) {
        this.brandSid = brandSid;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSid() {
        return supplierSid;
    }

    public void setSupplierSid(String supplierSid) {
        this.supplierSid = supplierSid;
    }
    public Integer getDbSupplierFlag() {
        return dbSupplierFlag;
    }

    public void setDbSupplierFlag(Integer dbSupplierFlag) {
        this.dbSupplierFlag = dbSupplierFlag;
    }
    public Integer getRelationEnabled() {
        return relationEnabled;
    }

    public void setRelationEnabled(Integer relationEnabled) {
        this.relationEnabled = relationEnabled;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getPushErpFlag() {
        return pushErpFlag;
    }

    public void setPushErpFlag(Integer pushErpFlag) {
        this.pushErpFlag = pushErpFlag;
    }

    public List<BrandRelationFlowVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<BrandRelationFlowVO> detailList) {
        this.detailList = detailList;
    }

    public String getPcUrl() {
        return pcUrl;
    }

    public void setPcUrl(String pcUrl) {
        this.pcUrl = pcUrl;
    }
}
